#' @keywords internal
#' @noRd
'_PACKAGE'

## usethis namespace: start
#' @importFrom cli col_blue col_green
#' @importFrom fs dir_copy
#' @importFrom glue glue
#' @importFrom here here
#' @importFrom quarto quarto_create_project quarto_version
#' @importFrom rappdirs user_config_dir
#' @importFrom readr read_file write_file
#' @importFrom rstudioapi openProject
#' @importFrom stringr str_replace str_to_lower
#' @importFrom usethis ui_done ui_info ui_oops ui_todo ui_warn ui_yeah
#' @importFrom utils download.file menu
#' @importFrom yaml read_yaml write_yaml
## usethis namespace: end
NULL